/*
 * Copyright (C) 2003-2005 the xine project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: snapshot.h,v 1.3 2005/01/03 22:06:04 dsalt Exp $
 *
 * gxine snapshot function
 */

#ifndef HAVE_SNAPSHOT_H
#define HAVE_SNAPSHOT_H

void make_snapshot (char *fname, int scale, int blend);
  /* -ve == from dbox, 0 == unscaled, +ve == scaled */

void snapshot_init (void);

#endif
